@@ -1,4 +1,3 @@
-from collections import ChainMap
 from dataclasses import dataclass, field
 from typing import Any, Callable, Iterator, MutableMapping, Tuple, Type
 
@@ -15,7 +14,7 @@ class BindingMap:
     _map: MutableMapping[Type[Any], Binding] = field(default_factory=dict)
 
     def chain(self) -> "BindingMap":
-        return BindingMap(ChainMap({}, self._map))
+        return BindingMap({**self._map})
 
     def __contains__(self, target: Type[Any]) -> bool:
         return target in self._map
@@ -26,5 +25,8 @@ class BindingMap:
     def __setitem__(self, target: Type[Any], binding: Binding) -> None:
         self._map[target] = binding
 
+    def __delitem__(self, target: Type[Any]) -> None:
+        del self._map[target]
+
     def items(self) -> Iterator[Tuple[Type[Any], Binding]]:
         yield from self._map.items()
